# {{NOTE_ID}} - {{TITLE}}

*One idea. Atomic. Permanently valuable.*

**Created**: {{DATE}}
**Tags**: #tag1 #tag2
**Status**: 🌱 Seedling | 🌿 Growing | 🌳 Mature

## Main Idea
*The core concept in your own words*


## Context
*Why is this important? How does it fit into broader understanding?*


## Supporting Details


## Related Notes
*Direct connections to other notes*

- [[Note ID - Title]] - Why connected
- [[Note ID - Title]] - Why connected


## Sources & References
*Where this idea came from*

-


## Questions & Thoughts
*Open questions, implications, applications*


---

**Principles:**
- One idea per note
- Write in your own words
- Always link to related notes
- Make it understandable to your future self
